@@ -1,13 +1,27 @@
 #' @rdname export
 #' @export
-export.scdf <- function(object, caption = NA, footnote = NA, filename = NA,
-                        kable_styling_options = list(), kable_options = list(),
-                        cols, ...) {
+export.scdf <- function(object, 
+                        summary = FALSE,
+                        caption = NA, 
+                        footnote = NA, 
+                        filename = NA,
+                        kable_styling_options = list(), 
+                        kable_options = list(),
+                        cols, 
+                        round = 2, 
+                        ...) {
+  
+  if (summary) {
+    sink(nullfile())
+    out <- summary(object)
+    sink()
+    return(export(out))
+  }
   
   kable_options <- .join_kabel(kable_options)
   kable_styling_options <- .join_kabel_styling(kable_styling_options)
   
-  if (!is.na(footnote)) {
+  if (is.na(footnote)) {
     if (!is.null(scdf_attr(object, "info"))) 
       footnote <- scdf_attr(object, "info")
     if (!is.null(scdf_attr(object, "author"))) {
@@ -24,11 +38,7 @@ export.scdf <- function(object, caption = NA, footnote = NA, filename = NA,
     cols <- names(object[[1]])
   }
   if (identical(cols, "main")) {
-    cols <- c(
-      scdf_attr(object, opt("phase")), 
-      scdf_attr(object, opt("dv")), 
-      scdf_attr(object, opt("mt"))
-    )
+    cols <- c(phase(object), dv(object), mt(object))
   }
   
   names(object) <- revise_names(object)
@@ -36,7 +46,7 @@ export.scdf <- function(object, caption = NA, footnote = NA, filename = NA,
   max_row <- max(unlist(lapply(object, nrow)))
   for (i in 1:cases) {
     n_row <- nrow(object[[i]])
-    object[[i]][, scdf_attr(object, opt("phase"))] <- as.character(object[[i]][, scdf_attr(object, opt("phase"))])
+    object[[i]][, phase(object)] <- as.character(object[[i]][, phase(object)])
     if (n_row < max_row) {
       object[[i]][(n_row + 1):max_row, names(object[[i]])] <- ""
     }
@@ -49,19 +59,27 @@ export.scdf <- function(object, caption = NA, footnote = NA, filename = NA,
   
   kable_options$align <- rep("c", ncol(out))
   
+  spanner <- setNames(vector("list", N), names(object))
+  n_vars <- ncol(out) / N
+  for(i in 1:N) {
+    spanner[[i]] <- ((i - 1) * n_vars + 1) : ((i - 1) * n_vars + n_vars)
+  }
+  
   table <- .create_table(
     out, 
     kable_options, 
     kable_styling_options, 
     caption = caption,
-    footnote = footnote
+    footnote = footnote,
+    spanner = spanner,
+    ...
   )
   
-  case_names <- rep(ncol(out) / N, N)
-  names(case_names) <- names(object)
-  table <- add_header_above(table, case_names)
-  if (!is.na(footnote) && footnote != "") 
-    table <- .add_footnote(table, footnote)
+  if (getOption("scan.export.engine") == "kable") {
+    case_names <- rep(n_vars, N)
+    names(case_names) <- names(object)
+    table <- add_header_above(table, case_names)
+  }
   
   # finish ------------------------------------------------------------------
   
@@ -69,5 +87,3 @@ export.scdf <- function(object, caption = NA, footnote = NA, filename = NA,
   
   table
 }
-
-
