@@ -3,8 +3,7 @@
 #' 
 print.sc_pem <- function(x, ...) {
   cat("Percent Exceeding the Median\n\n")
-  ma <- cbind(PEM = x$PEM, x$test)
-  print(round(ma, 3))
+  print(x$PEM, digits = 3, row.names = FALSE)
   cat("\n")
   if (x$decreasing) {
     cat("Assumed decreasing values in the B-phase.\n\n")
