@@ -1,8 +1,12 @@
 #' Subset cases, rows, and variables
 #'
+#' This function is mainly used to filter rows by a logical expression. It has
+#' also arguments to filter variables and cases.
+#'
 #' @param x An scdf object.
-#' @param ... [not implemented]
-#' @param filter Logical expression indicating rows to keep: missing values are taken as false.
+#' @param ... not implemented
+#' @param subset Logical expression indicating rows to keep: missing values are
+#'   taken as false.
 #' @param select Expression, indicating columns to select from an scdf.
 #' @param cases Expression, indicating cases to keep from an scdf.
 #'
@@ -10,15 +14,16 @@
 #' @export
 #'
 #' @examples
-#' subset(exampleAB, (values < 60 & phase == "A") | (values >= 60 & phase == "B"))
+#' exampleAB %>%
+#'   subset((values < 60 & phase == "A") | (values >= 60 & phase == "B"))
 #' subset(exampleAB_add, select = c(-cigarrets, -depression))
 #' subset(exampleAB, cases = c(Karolina, Johanna))
 #' subset(exampleA1B1A2B2, phase %in% c("A1", "B2"), cases = Pawel:Moritz)
 
-subset.scdf <- function(x, filter, select, cases, ...) {
+subset.scdf <- function(x, subset, select, cases, ...) {
   scdf <- x
   scdf_attributes <- attributes(scdf)
-  if (missing(filter)) filter <- TRUE else filter <- substitute(filter)
+  if (missing(subset)) subset <- TRUE else subset <- substitute(subset)
   if (missing(select)) select <- TRUE
   if (missing(cases)) cases <- TRUE
   
@@ -35,10 +40,10 @@ subset.scdf <- function(x, filter, select, cases, ...) {
     nl <- as.list(seq_along(x))
     names(nl) <- names(x)
     columns <- eval(substitute(select), nl, parent.frame())
-    # filter rows
-    if (isTRUE(filter)) rows <- TRUE
-    if (is.call(filter)) {
-      rows <- eval(filter, x, parent.frame())
+    # subset rows
+    if (isTRUE(subset)) rows <- TRUE
+    if (is.call(subset)) {
+      rows <- eval(subset, x, parent.frame())
       if (is.logical(rows))
         rows <- rows & !is.na(rows)
     }
