@@ -1,37 +1,55 @@
 
 server <- function(input, output, session) {
 
-  # Startup message
-  output$scdf_summary <- renderPrint(cat(res$msg$startup))
+  # scdf ----
+  
+  ## startup message ----
+  
+  output$scdf_messages <- renderPrint(cat(res$msg$startup))
 
+  ## Render ----
   my_scdf <- reactiveVal()
-
+  
   scdf_render <- reactive({
-
-    if (!inherits(my_scdf(), "scdf")) validate(res$msg$no_case)
-
-    output$scdf_summary <- renderPrint({
-      do.call("summary", list(my_scdf()))
-    })
-
-    output$scdf_syntax <- renderPrint({
-      req(inherits(my_scdf(), "scdf"))
-      do.call("convert", list(my_scdf(), inline = as.logical(input$convert)))
-    })
+    
+    if (input$scdf_output_format == "Summary"){
+      output$scdf_output <- renderPrint({
+        if (!inherits(my_scdf(), "scdf")) validate(res$msg$no_case)
+        if (identical(length(my_scdf()), 0)) validate(res$msg$no_case)
+        do.call("summary", list(my_scdf()))
+      })
+    } else if (input$scdf_output_format == "Syntax") {
+      output$scdf_output <- renderPrint({
+        if (!inherits(my_scdf(), "scdf")) validate(res$msg$no_case)
+        if (identical(length(my_scdf()), 0)) validate(res$msg$no_case)
+        do.call("convert", list(
+          my_scdf(), inline = as.logical(input$scdf_syntax_phase_structure)
+        ))
+      })
+    }
 
   })
 
+  observeEvent(input$scdf_output_format, scdf_render()) 
+  
+  ## input example ----
   observeEvent(input$scdf_example, {
     if (input$scdf_example != "(none)") {
       my_scdf(paste0("scan::", input$scdf_example) |> str2lang() |> eval())
       scdf_render()
+      output$load_messages <- renderPrint(
+        cat(paste0("loaded example ", input$scdf_example))
+      )
+      output$load_output <- renderPrint({
+        do.call("summary", list(my_scdf()))
+      })
+      output$scdf_messages <- renderPrint(cat(""))
     } else {
       my_scdf(NULL)
     }
   })
 
-
-  # scdf: upload / save ------
+  ## upload (load) ------
   observeEvent(input$upload, {
     ext <- tools::file_ext(input$upload$datapath)
     if (ext == "rds") {
@@ -43,44 +61,59 @@ server <- function(input, output, session) {
       eval(parse(text = new), envir = .tmp)
       new <- .tmp$study
     } else {
-      new <- read_scdf(input$upload$datapath)
+      na <- eval(str2lang(paste0("c(", input$scdf_load_na, ")")))
+      new <- read_scdf(input$upload$datapath, na = na)
     }
 
     if (!inherits(new, "scdf")) {
-      output$scdf_summary <- renderText(
-        "Sorry,\n the file you tried to upload is not a valid scdf file.")
+      output$load_messages <- renderText(
+        "Sorry,\n the file you tried to load is not a valid scdf file.")
     } else {
       my_scdf(new)
       scdf_render()
+      output$load_messages <- renderPrint(cat(paste0("loaded file successfully")))
+      output$load_output <- renderPrint({
+        do.call("summary", list(my_scdf()))
+      })
+      output$scdf_messages <- renderPrint(cat(""))
     }
 
   })
 
+  ## download (save) ----
   output$scdf_save <- downloadHandler(
     filename = function() {
       scdf <- my_scdf()
       out <- paste(
-        input$prefix_output_data,
+        input$scdf_save_prefix,
         sprintf("%02d", length(scdf)),
         paste0(unique(scdf[[1]]$phase), collapse = ""),
         format(Sys.time(), format = "%y%m%d-%H%M%S"),
         sep = "-"
       )
-      paste0(out, input$save_scdf_format)
+      paste0(out, input$scdf_save_format)
     },
+    
     content = function(file) {
       scdf <- my_scdf()
-      if (input$save_scdf_format == ".rds") 
+      
+      if (!inherits(scdf, "scdf")) {
+        output$scdf_messages <- renderPrint(cat(res$error_msg$scdf_save))
+      } else {
+        output$scdf_messages <- renderPrint(cat("Saved file"))
+      }
+      
+      if (input$scdf_save_format == ".rds") 
         saveRDS(scdf, file)
-      if (input$save_scdf_format == ".R") 
+      if (input$scdf_save_format == ".R") 
         convert(scdf, file = file)
-      if (input$save_scdf_format == ".csv") 
+      if (input$scdf_save_format == ".csv") 
         write_scdf(scdf, filename = file)
+
     }
   )
 
-  # scdf: new cases --------
-
+  ## new cases --------
   observeEvent(input$add_case, {
     tryCatch({
       values <- paste0("c(", trim(input$values), ")")
@@ -104,9 +137,11 @@ server <- function(input, output, session) {
         call <- c(call, variables)
       }
 
-      if (input$casename != "")
+      if (input$casename != "") {
         call <- c(call, paste0("name = ", deparse(input$casename)))
-
+      } else {
+        call <- c(call, paste0("name = \"case\""))
+      }
       call <- paste0(call, collapse = ",")
       call <- paste0("scdf(", call, ")")
 
@@ -114,6 +149,7 @@ server <- function(input, output, session) {
       if (input$remove_which == "last") {
         if (length(my_scdf()) > 0) new <- c(my_scdf(), new)
         my_scdf(new)
+        output$scdf_messages <- renderPrint(cat("Appended case"))
         scdf_render()
       } 
       
@@ -128,19 +164,20 @@ server <- function(input, output, session) {
             new <- c(my_scdf()[1:(at-1)], new, my_scdf()[at:(length(my_scdf()))])
           }
           my_scdf(new)
+          output$scdf_messages <- renderPrint(cat("Added case at position", input$remove_at))
           scdf_render() 
         }
       }  
 
     },
     error = function(e)
-      output$scdf_summary <- renderText(
+      output$scdf_messages <- renderText(
         paste0(res$error_msg$invalid_case, "\n\n", e)
       )
     )
   })
 
-  # scdf: remove cases --------
+  ## remove cases --------
   observeEvent(input$remove_case, {
     if (input$remove_which == "last") {
       if (length(my_scdf()) > 1) {
@@ -154,17 +191,21 @@ server <- function(input, output, session) {
         my_scdf(my_scdf()[-input$remove_at])
     }
     
+    output$scdf_messages <- renderPrint(cat("removed case"))
     scdf_render()
   })
 
-  # scdf: remove all cases --------
-  observeEvent(input$remove_all, {
+  ## clear cases --------
+  observeEvent(input$clear_cases, {
     my_scdf(NULL)
+    output$scdf_messages <- renderPrint(cat("Cleared cases"))
     scdf_render()
+    
   })
 
-  # transform ----
+  # Transform ----
 
+  ## render ----
   transformed <- reactive({
     out <- my_scdf()
     syntax = "scdf"
@@ -215,8 +256,8 @@ server <- function(input, output, session) {
     if (length(syntax)>1) {
       syntax <- syntax[-1]
       syntax <- paste0(
-        "scdf %>%\n  ",
-        paste0(syntax, collapse = " %>%\n  ")
+        "scdf", res$pipe_br, " ",
+        paste0(syntax, collapse = paste0(res$pipe_br, " "))
       )
 
     }
@@ -226,31 +267,30 @@ server <- function(input, output, session) {
     out
   })
 
-  # transform save ----
-  
+  ## save ----
   output$transformed_save <- downloadHandler(
     filename = function() {
       scdf <- transformed()
       out <- paste(
-        input$prefix_output_transformed,
+        input$transform_save_prefix,
         sprintf("%02d", length(scdf)),
         paste0(unique(scdf[[1]]$phase), collapse = ""),
         format(Sys.time(), format = "%y%m%d-%H%M%S"),
         sep = "-"
       )
-      paste0(out, input$save_transformed_format)
+      paste0(out, input$transform_save_format)
     },
     content = function(file) {
-      if (input$save_transformed_format == ".rds") 
+      if (input$transform_save_format == ".rds") 
         saveRDS(transformed(), file)
-      if (input$save_transformed_format == ".R") 
+      if (input$transform_save_format == ".R") 
         convert(transformed(), file = file)
-      if (input$save_transformed_format == ".csv") 
+      if (input$transform_save_format == ".csv") 
         write_scdf(transformed(), filename = file)
     }
   )
   
-  # transform output ------
+  ## output ------
   
   output$transform_scdf <- renderPrint({
     if(!inherits(my_scdf(), "scdf")) validate(res$msg$no_case)
@@ -259,15 +299,23 @@ server <- function(input, output, session) {
 
   output$transform_html <- renderUI({
     if(!inherits(my_scdf(), "scdf")) validate(res$msg$no_case)
-    export(transformed(), caption = "") |> HTML()
+    
+    options(scan.export.engine = input$scan_export_engine)
+    
+    if (getOption("scan.export.engine") == "gt")
+      export(transformed(), caption = "") |> gt::as_raw_html() |> HTML()
+    else
+      export(transformed(), caption = "") |> HTML()
+    
   })
   
-  # stats -----
+  # Stats -----
 
+  ## Calculate ---- 
   calculate_stats <- reactive({
     if (!inherits(my_scdf(), "scdf")) validate(res$msg$no_case)
     scdf <- transformed()
-    call <- get_stats_call()
+    call <- paste0("scan::", get_stats_call())
     tryCatch(
       str2lang(call) |> eval(),
       error = function(e)
@@ -275,17 +323,23 @@ server <- function(input, output, session) {
     )
   })
 
+  ## Output ----
   output$stats_html <- renderUI({
     results <- calculate_stats()
     print_args <- input$stats_print_arguments
+    flip <- paste0("flip = ", input$stats_export_flip)
+    options(scan.export.engine = input$scan_export_engine)
     if (print_args != "") {
       print_args <- paste0(", ", print_args)
-      call<- paste0("export(results, ", print_args, ")")
-    } else call <- "export(results)"
+      call<- paste0("export(results, ", flip, ", ", print_args, ")")
+    } else call <- paste0("export(results,", flip ,")")
     tryCatch(
-      str2lang(call) |> eval() |> HTML(),
+      if (getOption("scan.export.engine") == "gt")
+        str2lang(call) |> eval() |> gt::as_raw_html() |> HTML()
+      else
+        str2lang(call) |> eval() |> print() |> as.character() |> HTML(),
       error = function(e)
-        validate("Sorry, no html export for this function available yet.")
+        validate(paste0("Sorry, no html export for this function available yet.", "\n",e))
     )
   })
 
@@ -306,20 +360,23 @@ server <- function(input, output, session) {
   })
 
 
-  # stats: arguments ------
-
+  ## Arguments ------
   stat_arg_names <- reactive({
-    args <- names(formals(input$func))
-    values <- formals(input$func)
+    .formals <- formals(eval(str2lang(paste0("scan::", input$func))))
+    args <- names(.formals)
+    values <- .formals
 
     id <- which(!args %in% c(
       "dvar", "pvar", "mvar", "phases", "meta_method",
       "data", "scdf", "data.l2", "offset", "lag.max",
       "graph", "output", "...")
     )
-    args <- args[id]
-    values <- values[id]
-    list(names = args, values = values)
+    if (input$func == "mplm") {
+      id <- c(which(args == "dvar") , id)
+      values[which(args == "dvar")] <- scan:::dv(transformed())
+    }
+    
+    list(names = args[id], values = values[id])
   })
 
   output$stats_arguments <- renderUI({
@@ -344,12 +401,13 @@ server <- function(input, output, session) {
             value <- substitute(value) |> deparse()
           }
         }
-        if (input$stats_default == "Yes") outvalue <- value else outvalue = NULL
+        #if (input$stats_default == "Yes") outvalue <- value else outvalue = NULL
+        outvalue <- value
 
         if (length(value) > 1) {
           choices <- setNames(quoted(value), value)
-          if (input$stats_default == "No")
-            choices <- c("(default)" = "", choices)
+          #if (input$stats_default == "No")
+          #  choices <- c("(default)" = "", choices)
           selected <- names(choices)[1]
           out[[i]] <- selectInput(
             args$names[i], args$names[i],
@@ -362,8 +420,8 @@ server <- function(input, output, session) {
           )
         } else if (is.logical(value)) {
           choices <- c("FALSE", "TRUE")
-          if (input$stats_default == "No")
-            choices <- c("(default)" = "", choices)
+          #if (input$stats_default == "No")
+          #  choices <- c("(default)" = "", choices)
           out[[i]] <- radioButtons(
             args$names[i], args$names[i],
             choices = choices,
@@ -378,10 +436,33 @@ server <- function(input, output, session) {
   })
 
   get_stats_call <- reactive({
-    args <- stat_arg_names()
+    full_args <- stat_arg_names()
+    args <- full_args
     values <- sapply(args$names, function(name) input[[name]])
     args <- args$names
-
+    #print(full_args$values)
+    #print(values)
+    if (input$stats_default == "No") {
+      id_default <- mapply(
+        function(origin, new) {
+  
+          if (typeof(origin) == "language") origin <- eval(origin)
+          if (typeof(origin) == "symbol") origin <- deparse(origin)
+          if (identical(new, origin)) return(TRUE)
+          if (identical(new, as.character(origin[1]))) return(TRUE)
+          if (identical(new, deparse(origin))) return(TRUE)
+          
+          if (substr(deparse(origin[1]), 1,3) == "NA_") origin <- NA
+          if (identical(new, deparse(origin[1]))) return(TRUE)
+    
+          return(FALSE)
+        },
+        origin = full_args$values,
+        new = values
+      ) |> unlist()
+      values[id_default] <- ""
+    }
+    
     id <- which(values != "")
 
     args <- args[id]
@@ -399,7 +480,7 @@ server <- function(input, output, session) {
     call
   })
 
-  # stats save ------
+  ## Save ------
   
   output$stats_save <- downloadHandler(
     
@@ -412,14 +493,12 @@ server <- function(input, output, session) {
         format(Sys.time(), format = "%y%m%d-%H%M%S"),
         sep = "-"
       )
-      
-      if (input$stats_out == "Html") out <- paste0(out, ".html")
-      if (input$stats_out == "Text") out <- paste0(out, ".txt")
+      out <- paste0(out, ".", input$format_output_stats)
       out
     },
     content = function(file) {
       
-      if (input$stats_out == "Text") {
+      if (input$format_output_stats == "text") {
         results <- calculate_stats()
         print_args <- input$stats_print_arguments
         if (print_args != "") {
@@ -428,27 +507,50 @@ server <- function(input, output, session) {
         } else call <- "print(results)"
         call <- paste0("capture.output(", call, ")")
         writeLines(str2lang(call) |> eval(), con = file)
-      }
-      
-      if (input$stats_out == "Html") {
+      } else {
         results <- calculate_stats()
         print_args <- input$stats_print_arguments
         if (print_args != "") {
           print_args <- paste0(", ", print_args)
-          call<- paste0("export(results, ", print_args, ")")
+          call<- paste0(
+            "export(results, flip = ", input$stats_export_flip, ",",
+            print_args, 
+            ", filename = '", file, "')" 
+          )
         } else {
-          call <- "export(results)"
+          call <- paste0(
+            "export(results, flip = ", input$stats_export_flip,
+            ", filename = '", file, "')"
+            
+          )
         }
-        out <- str2lang(call) |> eval()
-        kableExtra::save_kable(out, file)
-        #writeLines(out, con = file)
+        
+        out <- if (getOption("scan.export.engine") == "gt")
+          str2lang(call) |> eval() |> gt::as_raw_html()
+        else
+          str2lang(call) |> eval()
+
       }
       
+      #if (input$stats_out == "Html") {
+      #  results <- calculate_stats()
+      #  print_args <- input$stats_print_arguments
+      #  if (print_args != "") {
+      #    print_args <- paste0(", ", print_args)
+      #    call<- paste0("export(results, ", print_args, ")")
+      #  } else {
+      #    call <- "export(results)"
+      #  }
+      #  out <- str2lang(call) |> eval()
+      #  kableExtra::save_kable(out, file)
+      #}
+      
     }
   )
   
-  # plot -----
+  # Plot -----
 
+  ## Render ----
   render_plot <- reactive({
     req(inherits(my_scdf(), "scdf"))
     call <- paste0("scplot(transformed())")
@@ -456,7 +558,7 @@ server <- function(input, output, session) {
       plot_args <- trimws(input$plot_arguments)
       plot_args <- gsub("\n+", "\n", plot_args)
       call <- paste0(
-        call, "%>% ", gsub("\n", " %>% ", plot_args)
+        call, res$pipe, gsub("\n", res$pipe, plot_args)
       )
     }
     call <- paste0("print(",call,")")
@@ -480,6 +582,19 @@ server <- function(input, output, session) {
   updateTextAreaInput(inputId = "plot_arguments", value = value)
   })
 
+  observeEvent(input$scplot_templates_annotate, {
+    new_value <- unname(
+      res$choices$scplot_templates_annotate[input$scplot_templates_annotate]
+    )
+    old_value <- input$plot_arguments
+    if (old_value == "") {
+      value <- new_value
+    } else {
+      value <- paste0(input$plot_arguments, "\n", new_value)
+    }
+    updateTextAreaInput(inputId = "plot_arguments", value = value)
+  })
+  
   observeEvent(input$scplot_examples, {
     if ("(empty selection)" == input$scplot_examples) {
       value <- ""
@@ -497,10 +612,25 @@ server <- function(input, output, session) {
 
   observeEvent(input$plot_arguments, render_plot_syntax())
 
-  output$plot_scdf <- renderPlot({
+  ## Output ----
+ 
+  render_plot_syntax <- reactive({
+    call <- paste0("scplot(scdf)")
+    if (trimws(input$plot_arguments) != "") {
+      call <- paste0(
+        call, res$pipe_br, " ", gsub("\n", paste0(res$pipe_br, " "), trimws(input$plot_arguments))
+      )
+    }
+    output$plot_syntax <- renderPrint({
+      cat(call)
+    })
+  })
+  
+  output$plot_scdf <- renderPlot(res = 120,{
     render_plot()
   })
 
+  ## Save ----
   output$saveplot <- downloadHandler(
     filename = function() {
       scdf <- transformed()
@@ -521,22 +651,108 @@ server <- function(input, output, session) {
     }
   )
 
-  render_plot_syntax <- reactive({
-    call <- paste0("scplot(scdf)")
-    if (trimws(input$plot_arguments) != "") {
-      call <- paste0(
-        call, "%>%\n  ", gsub("\n", " %>%\n  ", trimws(input$plot_arguments))
-      )
-    }
-    output$plot_syntax <- renderPrint({
-      cat(call)
-    })
+  # Power test -----
+  
+  output$pt_results <- renderPrint(cat(res$placeholder$pt))
+  
+  ## Render -----
+  render_power_test <- reactive({
+    syntax <- paste0(
+      "design(\n  n = ", input$design_n, ", ",
+      "phase_design = list(", input$design_phase, "), \n  ",
+      "trend = ", input$design_trend, ", ",
+      "level = list(", input$design_level, "), ",
+      "slope = list(", input$design_slope, "), \n  ",
+      "start_value = ", input$design_start, ", ",
+      #"s = ", input$design_s, ", ",
+      "rtt = ", input$design_rtt, ", ",
+      "distribution = ", deparse(input$design_distribution),
+      "\n)"
+    )  
+    
+    ci <- input$pt_ci
+   
+    syntax <- paste0(
+      syntax, res$pipe,
+      "  power_test(method = ", deparse(input$pt_method), ", ",
+      "effect = ", deparse(input$pt_effect), ", ",
+      "n_sim = ", input$pt_n, 
+      if (!identical(ci, "")) paste0(", ci = ", ci),
+      ")"
+    )
+    
+    syntax
   })
+  
+  ## Output ----
+  output$pt_syntax <- renderPrint({
+    cat(render_power_test())
+  })
+  
+  ## Plot ----
+  
+  observeEvent(input$desigh_plot_button, {
+    call <- paste0(
+      "design(\n  n = ", input$design_n, ", ",
+      "phase_design = list(", input$design_phase, "), \n  ",
+      "trend = ", input$design_trend, ", ",
+      "level = list(", input$design_level, "), ",
+      "slope = list(", input$design_slope, "), \n  ",
+      "start_value = ", input$design_start, ", ",
+      #"s = ", input$design_s, ", ",
+      "rtt = ", input$design_rtt, ", ",
+      "distribution = ", deparse(input$design_distribution),
+      "\n)", res$pipe,
+      "random_scdf()", res$pipe,
+      "scplot()"
+    )
+    
+    output$plot_design <- renderPlot(res = 100, {
+      str2lang(call) |> eval()
+    })
+    #tryCatch(
+    #  str2lang(call) |> eval(),
+    #  error = function(x)
+    #    output <- renderText(paste0(res$error_msg$plot, "\n\n", x))
+    #)
 
+  })
+  
+  ## Analyse ----
+  
+  observeEvent(input$pt_compute, {
+    
+    phase_structure <- eval(str2lang(
+      paste0("list(", input$design_phase, ")")
+    ))
+    if (length(phase_structure) > 2) {
+      output$pt_results <- renderPrint({
+        cat("Sorry, power-tests are only possible for designs with two phases.")
+      })
+    } else {
+      call <- render_power_test()
+      output$pt_results <- renderPrint({cat("Calculating ...")})
+      res <- tryCatch(
+        str2lang(call) |> eval(),
+        error = function(e)
+          paste0("Sorry, could not proceed calculation:\n\n", e)
+      )
+      output$pt_results <- renderPrint({
+        if (inherits(res, "character")) cat(res) else res
+      })
+    }
+    
+  })
+  
   # quit app -----
   observeEvent(input$navpage, {
     if (input$navpage == "Quit") {
+      session$sendCustomMessage(
+        type = "closeWindow", 
+        list(message = "window.close();")
+      )
       stopApp()
     }
   })
+  
 }
